attachments property
List of shared attachments (ex. images, videos, pdfs, etc.). Each attachment has an attachment type and a path to the file on the device.
Implementation
List<SharedAttachment>? attachments;
List of shared attachments (ex. images, videos, pdfs, etc.). Each attachment has an attachment type and a path to the file on the device.
List<SharedAttachment>? attachments;